==> piwigo-16.0.0.zip: piwigo/language/zh_CN/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Installation'] = '安装程序';
$lang['Basic configuration'] = '基本设置';
$lang['Default gallery language'] = '图库默认语言';
$lang['Database configuration'] = '数据库设置';
$lang['Admin configuration'] = '管理员帐户设置';
$lang['Start Install'] = '开始安装';
$lang['It will be shown to the visitors. It is necessary for website administration'] = '此帐户用于管理网站，所有访问者都能看到此帐户。';
$lang['Connection to server succeed, but it was impossible to connect to database'] = '服务器连接成功，但是无法连接到数据库。';
$lang['Can\'t connect to server'] = '无法连接到服务器';
$lang['Host'] = 'MySQL 主机地址';
$lang['User'] = '用户名';
$lang['user login given by your host provider'] = '数据库用户名（由主机服务商提供）';
$lang['user password given by your host provider'] = '数据库密码（由主机服务商提供）';
$lang['Database name'] = '数据库名称';
$lang['also given by your host provider'] = '也由您的主机供应商提供';
$lang['Database table prefix'] = '数据库表名称前缀';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = '本程序建立的所有表名都将加此前缀，以便您管理数据库';
$lang['enter a login for webmaster'] = '请输入站长的用户名';
$lang['webmaster login can\'t contain characters \' or "'] = '用户名不能包含字符 \' 或 "';
$lang['please enter your password again'] = '请再次输入密码';
$lang['Keep it confidential, it enables you to access administration panel'] = '请小心保管好此密码，您需要用此密码进入管理面板。';
$lang['Password [confirm]'] = '密码 [ 确认 ]';
$lang['verification'] = '请再次输入您的密码';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = '需要帮助吗？请到<a href="%s">Piwigo 论坛</a>提出您的问题。';
$lang['Visitors will be able to contact site administrator with this mail'] = '访问者将可通过此邮箱与站长取得联系';
$lang['PHP 5 is required'] = '需使用 PHP 5.3 版本';
$lang['It appears your webhost is currently running PHP %s.'] = '您主机上的 PHP 版本是 %s。';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo 会尝试创建或修改 .htaccess 文件以切换到 PHP 5.3。';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = '注意：你也可以自己修改设置 PHP 然后重新启动 Piwigo。';
$lang['Try to configure PHP 5'] = '尝试切换到 PHP 5.3';
$lang['Sorry!'] = '对不起!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo 无法切换到 PHP 5.3。';
$lang["You may referer to your hosting provider's support and see how you could switch to PHP 5 by yourself."] = '你应该联系你的主机管理员并向其请教如何设置PHP 5.';
$lang['Hope to see you back soon.'] = '稍后再会！';
$lang['Congratulations, Piwigo installation is completed'] = '恭喜，Piwigo 已安装完成';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = '另一个解决办法是，将以上文本框里的文本拷贝到 "local/config/database.inc.php" 文件里（注意：database.inc.php 必须只能包含此文本框里的内容，没有换行或者空格字符）';
$lang['Creation of config file local/config/database.inc.php failed.'] = '创建 local/config/database.inc.php 配置文件失败。';
$lang['Download the config file'] = '下载配置文件';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = '您可以下载配置文件，并上传到 local/config 目录以完成您的安装。';
$lang['Welcome to my photo gallery'] = '欢迎来到我的相册';
$lang['Just another Piwigo gallery'] = '一个崭新的 Piwigo 图库';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = '欢迎来我们的论坛咨询任何 Piwigo 相关问题：%s';
$lang['Welcome to your new installation of Piwigo!'] = '欢迎安装 Piwigo！';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = '您需要联系您的主机供应商，向其咨询如何自行切换为 PHP 5.3。';
$lang['localhost or other, supplied by your host provider'] = '数据库服务器的地址，由主机供应商提供';
$lang['Password ']['confirm'] = '密码确认';
$lang['PHP version %s required (you are running on PHP %s)'] = '需要 PHP %s 以上的版本（目前使用的是 PHP %s）';

==> piwigo-16.3.0.zip: piwigo/language/zh_CN/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Installation'] = '安装程序';
$lang['Basic configuration'] = '基本设置';
$lang['Default gallery language'] = '图库默认语言';
$lang['Database configuration'] = '数据库设置';
$lang['Admin configuration'] = '管理员帐户设置';
$lang['Start Install'] = '开始安装';
$lang['It will be shown to the visitors. It is necessary for website administration'] = '此帐户用于管理网站，所有访问者都能看到此帐户。';
$lang['Connection to server succeed, but it was impossible to connect to database'] = '服务器连接成功，但是无法连接到数据库。';
$lang['Can\'t connect to server'] = '无法连接到服务器';
$lang['Host'] = 'MySQL 主机地址';
$lang['User'] = '用户名';
$lang['user login given by your host provider'] = '数据库用户名（由主机服务商提供）';
$lang['user password given by your host provider'] = '数据库密码（由主机服务商提供）';
$lang['Database name'] = '数据库名称';
$lang['also given by your host provider'] = '也由您的主机供应商提供';
$lang['Database table prefix'] = '数据库表名称前缀';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = '本程序建立的所有表名都将加此前缀，以便您管理数据库';
$lang['enter a login for webmaster'] = '请输入站长的用户名';
$lang['webmaster login can\'t contain characters \' or "'] = '用户名不能包含字符 \' 或 "';
$lang['please enter your password again'] = '请再次输入密码';
$lang['Keep it confidential, it enables you to access administration panel'] = '请小心保管好此密码，您需要用此密码进入管理面板。';
$lang['Password [confirm]'] = '密码 [ 确认 ]';
$lang['verification'] = '请再次输入您的密码';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = '需要帮助吗？请到<a href="%s">Piwigo 论坛</a>提出您的问题。';
$lang['Visitors will be able to contact site administrator with this mail'] = '访问者将可通过此邮箱与站长取得联系';
$lang['PHP 5 is required'] = '需使用 PHP 5.3 版本';
$lang['It appears your webhost is currently running PHP %s.'] = '您主机上的 PHP 版本是 %s。';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo 会尝试创建或修改 .htaccess 文件以切换到 PHP 5.3。';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = '注意：你也可以自己修改设置 PHP 然后重新启动 Piwigo。';
$lang['Try to configure PHP 5'] = '尝试切换到 PHP 5.3';
$lang['Sorry!'] = '对不起!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo 无法切换到 PHP 5.3。';
$lang["You may referer to your hosting provider's support and see how you could switch to PHP 5 by yourself."] = '你应该联系你的主机管理员并向其请教如何设置PHP 5.';
$lang['Hope to see you back soon.'] = '稍后再会！';
$lang['Congratulations, Piwigo installation is completed'] = '恭喜，Piwigo 已安装完成';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = '另一个解决办法是，将以上文本框里的文本拷贝到 "local/config/database.inc.php" 文件里（注意：database.inc.php 必须只能包含此文本框里的内容，没有换行或者空格字符）';
$lang['Creation of config file local/config/database.inc.php failed.'] = '创建 local/config/database.inc.php 配置文件失败。';
$lang['Download the config file'] = '下载配置文件';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = '您可以下载配置文件，并上传到 local/config 目录以完成您的安装。';
$lang['Welcome to my photo gallery'] = '欢迎来到我的图库';
$lang['Just another Piwigo gallery'] = '一个崭新的 Piwigo 图库';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = '欢迎来我们的论坛咨询任何 Piwigo 相关问题：%s';
$lang['Welcome to your new installation of Piwigo!'] = '欢迎安装 Piwigo！';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = '您需要联系您的主机供应商，向其咨询如何自行切换为 PHP 5.3。';
$lang['localhost or other, supplied by your host provider'] = '数据库服务器的地址，由主机供应商提供';
$lang['Password ']['confirm'] = '密码确认';
$lang['PHP version %s required (you are running on PHP %s)'] = '需要 PHP %s 以上的版本（目前使用的是 PHP %s）';
